@@ -33,16 +33,50 @@ CtApp::CtApp() : Gtk::Application("com.giuspen.cherrytree", Gio::APPLICATION_HAN
 {
     Gsv::init();
 
-    std::string config_dir = Glib::build_filename(Glib::get_user_config_dir(), CtConst::APP_NAME);
-    if (g_mkdir_with_parents(config_dir.c_str(), 0755) < 0) {
-        spdlog::warn("Could not create config directory: {}", config_dir.c_str());
+    // action to call from second instance
+    // user wanted to create a new window from command line
+    add_action("new-window", [&]() {
+        if (_startup2)
+            _create_window()->present();
+    });
+
+    _add_main_option_entries();
+    signal_handle_local_options().connect(sigc::mem_fun(*this, &CtApp::_on_handle_local_options), false);
+
+    // This is normally called for us... but after the "handle_local_options" signal is emitted. If
+    // we want to rely on actions for handling options, we need to call it here. This appears to
+    // have no unwanted side-effect. It will also trigger the call to on_startup().
+    register_application();
+}
+
+CtApp::~CtApp()
+{
+    //std::cout << "~CtApp()" << std::endl;
+}
+
+/* static */ Glib::RefPtr<CtApp> CtApp::create()
+{
+    return Glib::RefPtr<CtApp>(new CtApp());
+}
+
+// small optimization: second instance doesn't need all UI initialization, so we call it on the real startup
+void CtApp::_on_startup()
+{
+    if (_startup2) return;
+    _startup2 = true;
+
+    const fs::path config_dir = fs::get_cherrytree_configdir();
+    if (not fs::exists(config_dir)) {
+        if (g_mkdir_with_parents(config_dir.c_str(), 0755) < 0) {
+            spdlog::warn("Could not create config directory: {}", config_dir.c_str());
+        }
     }
     _uCtCfg.reset(new CtConfig());
     //std::cout << _uCtCfg->specialChars.size() << "\t" << _uCtCfg->specialChars << std::endl;
 
-    std::string user_dir_icons = Glib::build_filename(Glib::get_user_config_dir(), CtConst::APP_NAME, "icons");
+    const fs::path user_dir_icons = config_dir / "icons";
     _rIcontheme = Gtk::IconTheme::get_default();
-    _rIcontheme->append_search_path(user_dir_icons);
+    _rIcontheme->append_search_path(user_dir_icons.string());
     _rIcontheme->add_resource_path("/icons/");
     //_print_gresource_icons();
 
@@ -83,23 +117,12 @@ CtApp::CtApp() : Gtk::Application("com.giuspen.cherrytree", Gio::APPLICATION_HAN
         systrayMenu->show_all();
         systrayMenu->popup(button, activate_time);
     });
-
-    _add_main_option_entries();
-    signal_handle_local_options().connect(sigc::mem_fun(*this, &CtApp::_on_handle_local_options), false);
-}
-
-CtApp::~CtApp()
-{
-    //std::cout << "~CtApp()" << std::endl;
-}
-
-Glib::RefPtr<CtApp> CtApp::create()
-{
-    return Glib::RefPtr<CtApp>(new CtApp());
 }
 
 void CtApp::on_activate()
 {
+    _on_startup();
+
     // start of main instance
     if (get_windows().size() == 0)
     {
@@ -145,6 +168,8 @@ void CtApp::on_activate()
 
 void CtApp::on_open(const Gio::Application::type_vec_files& files, const Glib::ustring& /*hint*/)
 {
+    _on_startup();
+
     // do some export stuff from console and close app after
     if ( not _export_to_txt_dir.empty() or
          not _export_to_html_dir.empty() or
@@ -335,6 +360,7 @@ void CtApp::_add_main_option_entries()
     add_main_option_entry(Gio::Application::OPTION_TYPE_FILENAME, "export_to_txt_dir",  't', _("Export to Text at specified directory path"));
     add_main_option_entry(Gio::Application::OPTION_TYPE_FILENAME, "export_to_pdf_file", 'p', _("Export to PDF at specified file path"));
     add_main_option_entry(Gio::Application::OPTION_TYPE_BOOL,     "export_overwrite",   'w', _("Overwrite if export path already exists"));
+    add_main_option_entry(Gio::Application::OPTION_TYPE_BOOL,     "new-window",         'N', _("Create a new window"));
 }
 
 void CtApp::_print_gresource_icons()
@@ -356,11 +382,19 @@ int CtApp::_on_handle_local_options(const Glib::RefPtr<Glib::VariantDict>& rOpti
         std::cout << "CherryTree " << CtConst::CT_VERSION << std::endl;
         return 0; // to exit app
     }
+
+    bool new_window = false;
     rOptions->lookup_value("node", _node_to_focus);
     rOptions->lookup_value("export_to_html_dir", _export_to_html_dir);
     rOptions->lookup_value("export_to_txt_dir", _export_to_txt_dir);
     rOptions->lookup_value("export_to_pdf_file", _export_to_pdf_file);
     rOptions->lookup_value("export_overwrite", _export_overwrite);
+    rOptions->lookup_value("new-window", new_window);
+
+    if (new_window) {
+        activate_action("new-window"); // will call 'new-window' action in primary instance
+        return 0; // to exit app
+    }
 
     return -1; // Keep going
 }
