@@ -394,14 +394,15 @@ const std::string CtMainWin::get_text_tag_name_exist_or_create(const std::string
         else if (CtConst::TAG_FAMILY == propertyName and CtConst::TAG_PROP_VAL_MONOSPACE == propertyValue)
         {
             rTextTag->property_family() = CtConst::TAG_PROP_VAL_MONOSPACE;
-            if (not _pCtConfig->monospaceBg.empty())
-            {
+            if (not _pCtConfig->monospaceBg.empty()) {
                 rTextTag->property_background() = _pCtConfig->monospaceBg;
             }
-            if (not _pCtConfig->monospaceFont.empty())
-            {
+            if (_pCtConfig->msDedicatedFont and not _pCtConfig->monospaceFont.empty()) {
                 rTextTag->property_font() = _pCtConfig->monospaceFont;
             }
+            else {
+                rTextTag->property_family() = CtConst::TAG_PROP_VAL_MONOSPACE;
+            }
         }
         else if (CtConst::TAG_STRIKETHROUGH == propertyName and CtConst::TAG_PROP_VAL_TRUE == propertyValue)
         {
