@@ -267,8 +267,11 @@ std::unique_ptr<xmlpp::DomParser> CtStorageXml::_get_parser(const fs::path& file
         spdlog::error("CtStorageXml::_get_parser: failed to read xml file {}, {}", file_path.string(), e.what());
         spdlog::info("CtStorageXml::_get_parser: trying to sanitize xml file ...");
 
-        Glib::ustring buffer = fs::get_content(file_path);
-        CtStrUtil::convert_from_bom(buffer);
+        std::string buffer = fs::get_content(file_path);
+        const std::string codeset = CtStrUtil::get_encoding(buffer.c_str(), buffer.size());
+        if (CtStrUtil::is_codeset_not_utf8(codeset)) {
+            buffer = Glib::convert_with_fallback(buffer, "UTF-8", codeset);
+        }
         Glib::ustring xml_content = str::sanitize_bad_symbols(buffer);
         parser->parse_memory(xml_content);
         spdlog::info("CtStorageXml::_get_parser: xml file is sanitized");
@@ -533,3 +536,33 @@ CtAnchoredWidget* CtStorageXmlHelper::_create_table_from_xml(xmlpp::Element* xml
 
     return new CtTable(_pCtMainWin, tableMatrix, colWidthDefault, charOffset, justification, tableColWidths);
 }
+
+namespace CtXmlHelper
+{
+    void table_to_xml(xmlpp::Element* p_parent, const std::vector<std::vector<Glib::ustring>>& rows, int char_offset, Glib::ustring justification, int defaultWidth, Glib::ustring colWidths)
+    {
+        xmlpp::Element* p_table_node = p_parent->add_child("table");
+        p_table_node->set_attribute("char_offset", std::to_string(char_offset));
+        p_table_node->set_attribute(CtConst::TAG_JUSTIFICATION, justification);
+        p_table_node->set_attribute("col_min", std::to_string(defaultWidth)); // todo get rid of column min
+        p_table_node->set_attribute("col_max", std::to_string(defaultWidth));
+        p_table_node->set_attribute("col_widths", colWidths);
+
+        auto row_to_xml = [&](const std::vector<Glib::ustring>& tableRow) {
+            xmlpp::Element* row_element = p_table_node->add_child("row");
+            for (const auto& cell : tableRow) {
+                xmlpp::Element* cell_element = row_element->add_child("cell");
+                cell_element->set_child_text(cell);
+            }
+        };
+
+        // put header at the end
+        bool is_header = true;
+        for (auto& row: rows)
+        {
+            if (is_header) { is_header = false; }
+            else row_to_xml(row);
+        }
+        row_to_xml(rows[0]);
+    }
+};
